Display

Struct Display 

pub struct Display<T: Tui> { /* private fields */ }
A high level interface to the terminal display.

Implementations

Source

impl<T: Tui> Display<T>

pub fn new(tui: T, theme: &Theme) -> Self

Create a new display instance.

pub fn draw_str(&mut self, s: &str) -> Result<(), DisplayError>

Draws a string of text to the terminal interface.

Errors

Will error if the underlying terminal interface is in an error state.

pub fn clear(&mut self) -> Result<(), DisplayError>

Clear the terminal interface and reset any style and color attributes.

Errors

Will error if the underlying terminal interface is in an error state.

pub fn refresh(&mut self) -> Result<(), DisplayError>

Force a refresh of the terminal interface. This normally should be called after after all text has been drawn to the terminal interface. This is considered a slow operation, so should be called only as needed.

Errors

Will error if the underlying terminal interface is in an error state.

pub fn color( &mut self, color: DisplayColor, selected: bool, ) -> Result<(), DisplayError>

Set the color of text drawn to the terminal interface. This will only change text drawn to the terminal after this function call.

Errors

Will error if the underlying terminal interface is in an error state.

pub fn set_style( &mut self, dim: bool, underline: bool, reverse: bool, ) -> Result<(), DisplayError>

Set the style attributes of text drawn to the terminal interface. This will only change text drawn to the terminal after this function call.

Errors

Will error if the underlying terminal interface is in an error state.

pub fn get_window_size(&self) -> Size

Get the width and height of the terminal interface. This can be a slow operation, so should not be called unless absolutely needed.

Errors

Will error if the underlying terminal interface is in an error state.

pub fn ensure_at_line_start(&mut self) -> Result<(), DisplayError>

Reset the cursor position to the start of the line.

Errors

Will error if the underlying terminal interface is in an error state.

pub fn move_from_end_of_line(&mut self, right: u16) -> Result<(), DisplayError>

Move the cursor position right characters from the end of the line.

Errors

Will error if the underlying terminal interface is in an error state.

pub fn next_line(&mut self) -> Result<(), DisplayError>

Move the cursor to the next line.

Errors

Will error if the underlying terminal interface is in an error state.

pub fn start(&mut self) -> Result<(), DisplayError>

Start the terminal interface interactions. This should be called before any terminal interactions are performed.

Errors

Will error if the underlying terminal interface is in an error state.

pub fn end(&mut self) -> Result<(), DisplayError>

End the terminal interface interactions. This should be called after all terminal interactions are complete. This resets the terminal interface to the default state, and should be called on program exit.

Errors

Will error if the underlying terminal interface is in an error state.