assert_output

Function assert_output 

pub fn assert_output(display: &Display<CrossTerm>, expected: &[&str])
Assert the the content of the Display is an expected value.

Panics

Will panic is the expected output does not match the rendered output.